@@ -17,7 +17,7 @@ pub mod fetch;
 #[cfg(any(feature = "blocking-client", feature = "async-client"))]
 mod fetch_fn;
 #[cfg(any(feature = "blocking-client", feature = "async-client"))]
-pub use fetch_fn::fetch;
+pub use fetch_fn::{fetch, FetchConnection};
 
 mod remote_progress;
 pub use remote_progress::RemoteProgress;
